"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const tasks_1 = require("@angular-devkit/schematics/tasks");
const utils_1 = require("../utils");
const core_1 = require("@angular-devkit/core");
function getWorkspace(host) {
    const possibleFiles = ['/angular.json', '/.angular.json', '/workspace.json'];
    const path = possibleFiles.filter(path => host.exists(path))[0];
    const configBuffer = host.read(path);
    if (configBuffer === null) {
        throw new schematics_1.SchematicsException(`Could not find angular.json or workspace.json`);
    }
    const content = configBuffer.toString();
    let workspace;
    try {
        workspace = core_1.parseJson(content, core_1.JsonParseMode.Loose);
    }
    catch (e) {
        throw new schematics_1.SchematicsException(`Could not parse angular.json or workspace.json: ` + e.message);
    }
    return {
        path,
        workspace
    };
}
function addDeployBuilderToProject(tree, options) {
    const { path: workspacePath, workspace } = getWorkspace(tree);
    if (!options.project) {
        if (workspace.defaultProject) {
            options.project = workspace.defaultProject;
        }
        else {
            throw new schematics_1.SchematicsException('No Angular project selected and no default project in the workspace');
        }
    }
    const project = workspace.projects[options.project];
    if (!project) {
        throw new schematics_1.SchematicsException('The specified Angular project is not defined in this workspace');
    }
    if (project.projectType !== 'application') {
        throw new schematics_1.SchematicsException(`Deploy requires an Angular project type of "application" in angular.json`);
    }
    if (!project.architect ||
        !project.architect.build ||
        !project.architect.build.options ||
        !project.architect.build.options.outputPath) {
        throw new schematics_1.SchematicsException(`Cannot read the output path (architect.build.options.outputPath) of the Angular project "${options.project}" in angular.json`);
    }
    project.architect['deploy'] = {
        builder: 'ngx-deploy-docker:deploy',
        options: {
            userName: options.userName
        }
    };
    tree.overwrite(workspacePath, JSON.stringify(workspace, null, 2));
}
function prepareDockerFiles(host, context, options) {
    const sourceTemplates = schematics_1.url('./files');
    const version = utils_1.getVersionFromPackageJson(host);
    const sourceParametrizedTemplates = schematics_1.apply(sourceTemplates, [
        schematics_1.template(Object.assign({}, options, core_1.strings, { version }))
    ]);
    return schematics_1.mergeWith(sourceParametrizedTemplates)(host, context);
}
function default_1(options) {
    return (host, context) => {
        const version = utils_1.getLibraryVersion();
        utils_1.addPackageToPackageJson(host, 'ngx-deploy-docker', `^${version}`);
        context.logger.log('info', `🐳  Added "ngx-deploy-docker@^${version}" into devDependencies`);
        if (options.skipInstall) {
            context.logger.log('warn', `❗️  The "--skip-install" flag was present, don't forget to install package manually`);
        }
        else {
            context.logger.log('info', `📦  Installing added packages...`);
            context.addTask(new tasks_1.NodePackageInstallTask());
        }
        addDeployBuilderToProject(host, options);
        context.logger.log('info', `🚀  Deploy Builder added to your project`);
        context.logger.log('info', 'Preparing some 🐳 files...');
        return prepareDockerFiles(host, context, options);
    };
}
exports.default = default_1;
//# sourceMappingURL=index.js.map