"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const child_process = __importStar(require("child_process"));
function getImageNameWithTag(options) {
    return options.account !== ''
        ? `${options.account}/${options.imageName}:${options.tag}`
        : `${options.imageName}:${options.tag}`;
}
function buildDockerImage(imageNameWithTag, logger) {
    return __awaiter(this, void 0, void 0, function* () {
        const child = child_process.spawn('docker', ['build', '-t', imageNameWithTag, '.'], {
            stdio: 'pipe'
        });
        child.stdout.on('data', data => {
            logger.info(data.toString());
        });
        child.stderr.on('data', data => {
            logger.error(data.toString());
        });
        return new Promise(resolve => {
            child.on('close', code => {
                resolve();
            });
        });
    });
}
function publishDockerImage(imageNameWithTag, logger) {
    return __awaiter(this, void 0, void 0, function* () {
        const child = child_process.spawn('docker', ['push', imageNameWithTag], {
            stdio: 'pipe'
        });
        child.stdout.on('data', data => {
            logger.info(data.toString());
        });
        child.stderr.on('data', data => {
            logger.error(data.toString());
        });
        return new Promise(resolve => {
            child.on('close', code => {
                resolve();
            });
        });
    });
}
function run(options, logger) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const imageNameWithTag = getImageNameWithTag(options);
            logger.info('🚧 Executing Docker Build...');
            yield buildDockerImage(imageNameWithTag, logger);
            logger.info('✔️ Docker Build was successfully');
            logger.info('🚀 Publishing image to registry');
            yield publishDockerImage(imageNameWithTag, logger);
            logger.info('🎊 Successfully published image. Have a nice day.');
        }
        catch (error) {
            logger.error('❌ An error occurred!');
            throw error;
        }
    });
}
exports.run = run;
//# sourceMappingURL=engine.js.map